logs_spotter library

Classes

Functions
SpotEntry
Model for a log entry
Spotter
SpotterSession
Model for a session, containing multiple log entries

Extensions

Spot on String

Constants

click → const String
DEFAULT_LOG_TAG for ui click event. Icon: 🖱️
debug → const String
DEFAULT_LOG_TAG for debug. Icon: 🐞
defaultFileName → const String
local writing default file name
error → const String
DEFAULT_LOG_TAG for error. Icon: 🚨
request → const String
DEFAULT_LOG_TAG for api or public method request event. Icon: 📤
response → const String
DEFAULT_LOG_TAG for api or public method response event. Icon: 📥
warning → const String
DEFAULT_LOG_TAG for warning. Icon: 🚧

Properties

penAPIRequest ↔ AnsiPen
DEFAULT_AnsiPen color (white) for console style
getter/setter pair
penAPIResponse ↔ AnsiPen
DEFAULT_AnsiPen color (white) for console style
getter/setter pair
penClick ↔ AnsiPen
DEFAULT_AnsiPen color (white) for console style
getter/setter pair
penError ↔ AnsiPen
DEFAULT_AnsiPen color (red) for console style
getter/setter pair
penFine ↔ AnsiPen
DEFAULT_AnsiPen color (green) for console style
getter/setter pair
penInfo ↔ AnsiPen
DEFAULT_AnsiPen color (white) for console style
getter/setter pair
penWarning ↔ AnsiPen
DEFAULT_AnsiPen color (yellow) console style
getter/setter pair

Functions

getAppName() Future<String?>
Package internal method to get Application name
getPackageName() Future<String?>
Package internal method to get Application name
icon(dynamic tag) String
Package internal methode to determine emoji from log tag
provideDefaultId() Future<String>
Package internal method to create a default customId even there are null on Spotter().initializeEngine()
provideDeviceInfo() Future<Map<String, dynamic>>
Package internal method to collect more data about device