SpotEntry class
Model for a log entry
Constructors
Properties
- dateTime ↔ DateTime
-
log time
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ String?
-
log level
getter/setter pair
- message → String
-
log content
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag ↔ String?
-
log TAG
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAnsiPen(
) → String -
toJson(
) → Map< String, dynamic> - Convert Model SpotEntry object to Map
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited