Spotter class

Constructors

Spotter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encryptMessage(String plainText) String
getUserLabel() String?
initialize(String url, String anonKey) → void
set_UserLabel(String label) → dynamic