SpotterSession class

Model for a session, containing multiple log entries

Constructors

SpotterSession({required int sessionId, required String customId})
Model constructor

Properties

customId String
final
entries List<SpotEntry>
log entry list
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int
Session identifier
final

Methods

addEntry(SpotEntry entry) → void
Add entry to list entries
formatSession() String
Print all session to String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited